#!/bin/bash

app_name="bun"
tmp_dir="/tmp/${app_name}_tmp"
version="1.1.29"
release="v${version}"
pkg_arch="x64"
deb_arch="amd64"

if [ "$1" == "arm" ]; then
  pkg_arch="aarch64"
  deb_arch="arm64"
fi


deb_url="https://github.com/oven-sh/bun/releases/download/bun-${release}/bun-linux-${pkg_arch}.zip"

# 创建临时目录, 用于下载官方包
if [ -d $tmp_dir ]; then
  rm -rf $tmp_dir
fi

if [ -d "./unpack" ]; then
  sudo rm -rf ./unpack
fi

if [ -f "./${app_name}_${version}.deb" ]; then
  rm "./${app_name}_${version}.deb"
fi

mkdir $tmp_dir

# 创建临时待打包目录
echo "创建待打包目录..."
mkdir -p "./unpack/DEBIAN"
mkdir -p "./unpack/usr/bin"

echo "下载官方原包..."
wget $deb_url -O "${tmp_dir}/bun-linux-${pkg_arch}.zip"


echo "下载完成, 解包中..."
unzip "${tmp_dir}/bun-linux-${pkg_arch}.zip" -d $tmp_dir

echo "解包完成, 复制到待打包目录..."
mv ${tmp_dir}/bun-linux-${pkg_arch}/* "./unpack/usr/bin/"

rm -rf $tmp_dir

echo "复制完成, 计算文件md5..."

cd ./unpack

find usr/ -type f | xargs md5sum > DEBIAN/md5sums

IFS=$'\t' read -ra size <<< "$(du -d 0)"

echo """
Package: ${app_name}
Version: ${version}
Section: devlop
Installed-Size: ${size[0]}
Architecture: ${deb_arch}
Maintainer: Yutent <yutent.io@gmail.com>
Priority: optional
Homepage: https://bun.sh/
Description: Incredibly fast JavaScript runtime.
  Incredibly fast JavaScript runtime, bundler, transpiler and package manager - all in one.

""" > DEBIAN/control

echo '计算文件md5完成, 打包中...'

cd ..
sudo chown -R root:root unpack

dpkg-deb -b ./unpack "./${app_name}-${deb_arch}_${version}.deb"

sudo rm -rf ./unpack
echo "打包完成 :)"
